@@ -123,6 +123,9 @@ _('jupyter_slider_width', '80%',
   doc='CSS Width used by an interactive slider in jupyter')
 _('timeout', 2.,
   doc='Timeout for any action waiting a response from csound')
+_('sched_latency', 0.,
+  doc='Time delay added to any event scheduled to ensure that simultameous events are'
+      'not offset by scheduling overhead')
 
 assert 'num_control_buses' in config.default
 config.load()
